urn_nbn_api.api_structures package
==================================

Submodules
----------

.. toctree::

   urn_nbn_api.api_structures.catalog
   urn_nbn_api.api_structures.digital_instance
   urn_nbn_api.api_structures.digital_library
   urn_nbn_api.api_structures.kwarg_obj
   urn_nbn_api.api_structures.modes
   urn_nbn_api.api_structures.registrar
   urn_nbn_api.api_structures.tools
   urn_nbn_api.api_structures.urn_nbn

Module contents
---------------

.. automodule:: urn_nbn_api.api_structures
    :members:
    :undoc-members:
    :show-inheritance:
